@@ -29,10 +29,10 @@ They are written in yaml format to be easily readable as well as flexible and po
 A simple Magma file looks like the following:: 
     #MAGMAv0.4
     files:
-    - name: input_file.txt
+    - filename: input_file.txt
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
-    - name: input_file2.txt
+    - filename: input_file2.txt
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
 
@@ -49,13 +49,14 @@ An example magma file is I{example-0.4.magma}.
 
 This API documentation is avaible from U{http://gnuticles.gnufu.net/pymagma/}, and the code is avaible from a U{Mercurial repository <http://freehg.org/u/ArneBab/magma/>}. 
 
-The module can also be found in the U{Python Package Index (PyPI) <http://pypi.python.org/pypi/magma/>}. 
+The module can also be found in the U{Python Package Index (PyPI) <http://pypi.python.org/pypi/magma/>}. It is available under the GPL-3 or later. 
+
+It is being written by U{Arne Babenhauserheide <http://draketo.de>}. If you wish to contribute, please drop me a mail with the word "tunnel" somewhere in the subject line (to get past my spamfilter). My email: arne_bab at web de . 
 
 Usage of this module
 ====================
 
-from magma import Magma
-
+    >>> # from magma import Magma
     >>> magma = Magma(magma_file="example-0.4.magma")
 
 or 
@@ -68,33 +69,32 @@ API / usage
 
 B{Creating magma lists from input files}
     
-Then create a list from input files. 
+Create a list from input files. 
     >>> magma = Magma(input_files=["input_file.txt"])
     
 And save the list. 
     >>> magma.save(path="example.magma")
     
-Or output the list. 
+Or output the it. 
     >>> print magma
     #MAGMAv0.4
     files:
-    - name: input_file.txt
+    - filename: input_file.txt
       urn:
         sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
     <BLANKLINE>
     
-Or just return a list of its files. 
+Or just return a list of its files as MagmaFiles. 
     >>> files = magma.files
     
-or output all magnet links inside the magma list. 
-   >>> magnets = magma.magnets
-   >>> print magnets
+Or output all magnet links inside the magma list. 
+   >>> print magma.magnets
    ['magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
   
   
 B{Reading from magma lists}
    
-Then create the list. 
+Create the list. 
    >>> magma = Magma(magma_file="example.magma")
    
 Now get the files
@@ -108,18 +108,16 @@ Get the first file from the list.
    input_file.txt 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
    
 And output its magnet. 
-   >>> file_magnet = one_file.magnet
-   >>> print file_magnet
+   >>> print one_file.magnet
    magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt
    
 Or output all its (meta-) data. 
-   >>> file_data = one_file.data
-   >>> print file_data
-   {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'name': 'input_file.txt'}
+   >>> print one_file.data
+   {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'filename': 'input_file.txt'}
    
+
 Output all magnet links inside the magma list. 
-   >>> magnets = magma.magnets
-   >>> print magnets
+   >>> print magma.magnets
    ['magnet:?xt=urn:sha1:3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G&dn=input_file.txt']
 
 
@@ -139,6 +137,16 @@ Also dump yaml data via magma.dump()
    {}
    <BLANKLINE>
 
+Or just open a Magma file from its path. 
+    >>> magma = open_file("example.magma")
+    >>> print magma
+    #MAGMAv0.4
+    files:
+    - filename: input_file.txt
+      urn:
+        sha1: 3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
+    <BLANKLINE>
+
 
 Plans: 
     - Also pass metadata and include that alongside the file list. 
@@ -164,13 +172,13 @@ __copyright__ = 'Copyright (C) 2008 Arne Babenhauserheide'
 __date__ = '2008-05-09'
 __licence__ = 'GPL-3 or later'
 __program__ = 'MAGnet MAnifest Management'
-__version__ = '0.2.8'
+__version__ = '0.2.9'
 
 # The dependencies of the _init__ only. 
 __depends__ = ''
 
 def parse_dependencies(init_depends):
-    """Aggregate the dependencies from ann submodules.
+    """Aggregate the dependencies from all submodules.
     
     @param init_depends: The dependencies of the __init__ file. 
     @type init_depends: String 
@@ -203,6 +211,15 @@ __depends__ = parse_dependencies(__depends__)
 
 from magma_list import Magma
 
+def open_file(filepath):
+    """Open a file as Magma list and produce the corresponding Python object.
+    
+    @param yaml_data: Data read from a yaml file
+    @type yaml_data: String
+    @return: A Magma Object. 
+    """
+    return Magma(magma_file=filepath)
+
 def load(yaml_data):
     """Parse a Magma list and produce the corresponding Python object.
     
@@ -227,7 +244,7 @@ def dump(magma):
 #### Self-Test ####
 
 def _test():
-    """Do all doctests
+    """Do all doctests.
     
     @return: None
     """
